summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/include/arch.h
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/arm/include/arch.h')
-rw-r--r--nuttx/arch/arm/include/arch.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/nuttx/arch/arm/include/arch.h b/nuttx/arch/arm/include/arch.h
index 426f4b959..dd750ad77 100644
--- a/nuttx/arch/arm/include/arch.h
+++ b/nuttx/arch/arm/include/arch.h
@@ -45,6 +45,9 @@
****************************************************************************/
#include <nuttx/config.h>
+#ifndef __ASSEMBLY__
+# include <stdint.h>
+#endif
/****************************************************************************
* Definitions
@@ -60,14 +63,14 @@
#define PIC_REG_STRING "r10"
/* Macros to get and set the PIC base register. picbase is assumed to be
* of type (void*) and that it will fit into a uint32. These must be
* inline so that they will be compatible with the ABIs rules for
* preserving the PIC register
*/
#define up_getpicbase(ppicbase) \
do { \
- uint32 picbase; \
+ uint32_t picbase; \
__asm__ \
( \
"\tmov %0, " PIC_REG_STRING "\n\t" \
@@ -78,7 +81,7 @@ do { \
#define up_setpicbase(picbase) \
do { \
- uint32 _picbase = (uint32)picbase; \
+ uint32_t _picbase = (uint32_t)picbase; \
__asm__ \
( \
"\tmov " PIC_REG_STRING ", %0\n\t" \
@@ -60,14 +63,14 @@
#define PIC_REG_STRING "r10"
/* Macros to get and set the PIC base register. picbase is assumed to be
- * of type (void*) and that it will fit into a uint32. These must be
+ * of type (void*) and that it will fit into a uint32_t. These must be
* inline so that they will be compatible with the ABIs rules for
* preserving the PIC register